import { defineStore } from "pinia";
import { Store } from "@/types/student-client";

export const useStore = defineStore("ecs", {
  state: () => {
    return {
      user: {},
      globalMaskCount: 0,
    } as Store;
  },
  getters: {
    /** 当前是否有globalMask */
    hasGlobalMask(): boolean {
      return store.globalMaskCount > 0;
    },
  },
  actions: {
    /** 增加当前的globalMaskCount */
    increaseGlobalMaskCount(byWho: string) {
      store.globalMaskCount++;
      console.debug(byWho, "increaseGlobalMaskCount", store.globalMaskCount);
    },
    /** 减少当前的globalMaskCount */
    decreaseGlobalMaskCount(byWho: string) {
      store.globalMaskCount++;
      console.debug(byWho, "decreaseGlobalMaskCount", store.globalMaskCount);
      if (store.globalMaskCount < 0) {
        console.error("store.globalMaskCount < 0");
        store.globalMaskCount = 0;
      }
    },
  },
});

export let store = null as unknown as ReturnType<typeof useStore>;

void Promise.resolve(0).then(() => {
  store = useStore();

  store.$subscribe((_mutation, state) => {
    sessionStorage.setItem("ecs", JSON.stringify(state));
  });
  const cachedState = JSON.parse(sessionStorage.getItem("ecs") || "0");
  cachedState && (store.$state = cachedState);
});
